@@ -1,24 +1,27 @@
-# coding: utf-8
-
 from django import forms
+from django.conf import settings
 from django.forms.models import modelform_factory
 from django.utils.translation import gettext as _
 from wagtail.admin import widgets
 from wagtail.admin.forms.collections import (
-    BaseCollectionMemberForm, CollectionChoiceField, collection_member_permission_formset_factory)
+    BaseCollectionMemberForm,
+    CollectionChoiceField,
+    collection_member_permission_formset_factory,
+)
 from wagtail.core.models import Collection
 from wagtail.images.edit_handlers import AdminImageChooser
 
 from wagtail_embed_videos.models import EmbedVideo
-from wagtail_embed_videos.permissions import \
-    permission_policy as embed_videos_permission_policy
+from wagtail_embed_videos.permissions import permission_policy as embed_videos_permission_policy
 
 
 # Callback to allow us to override the default form field for the collection field.
 def formfield_for_dbfield(db_field, **kwargs):
     # Check if this is the collection field
-    if db_field.name == 'collection':
-        return CollectionChoiceField(queryset=Collection.objects.all(), empty_label=None, **kwargs)
+    if db_field.name == "collection":
+        return CollectionChoiceField(
+            label=_("Collection"), queryset=Collection.objects.all(), empty_label=None, **kwargs
+        )
 
     # For all other fields, just call its formfield() method.
     return db_field.formfield(**kwargs)
@@ -27,6 +30,23 @@ def formfield_for_dbfield(db_field, **kwargs):
 class BaseEmbedVideoForm(BaseCollectionMemberForm):
     permission_policy = embed_videos_permission_policy
 
+    class Meta:
+        widgets = {
+            "tags": widgets.AdminTagWidget,
+            "thumbnail": AdminImageChooser,
+        }
+
+
+def get_embed_video_base_form():
+    base_form_override = getattr(settings, "WAGTAILEMBEDVIDEOS_EMBEDVIDEO_FORM_BASE", "")
+    if base_form_override:
+        from django.utils.module_loading import import_string
+
+        base_form = import_string(base_form_override)
+    else:
+        base_form = BaseEmbedVideoForm
+    return base_form
+
 
 def get_embed_video_form(model):
     fields = model.admin_form_fields
@@ -39,13 +59,9 @@ def get_embed_video_form(model):
 
     return modelform_factory(
         model,
-        form=BaseEmbedVideoForm,
+        form=get_embed_video_base_form(),
         fields=fields,
         formfield_callback=formfield_for_dbfield,
-        widgets={
-            "tags": widgets.AdminTagWidget,
-            "thumbnail": AdminImageChooser,
-        },
     )
 
 
@@ -58,6 +74,7 @@ GroupEmbedVideoPermissionFormSet = collection_member_permission_formset_factory(
     [
         ("add_embedvideo", _("Add"), _("Add/edit embed videos you own")),
         ("change_embedvideo", _("Edit"), _("Edit any embed video")),
+        ("choose_embedvideo", _("Choose"), _("Select embed videos in choosers")),
     ],
     "wagtail_embed_videos/permissions/includes/embedvideo_permissions_formset.html",
 )
